//
// return content of xml 
// (used for VOSI capabilityVOSI and availability.xml)
//

import java.io.IOException;
import java.io.PrintWriter;
import java.io.File;
import java.io.OutputStream;
import java.util.Enumeration;
import java.util.*; // ArrayList<String>

import javax.servlet.ServletConfig;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.ServletOutputStream; // for SOOA

import java.io.*;

import java.nio.file.*;
import static java.nio.file.StandardCopyOption.*;


// serve VOSI resources from xml files (for now implemented as strings, not files FIXME)

public class VosiServlet
    extends javax.servlet.http.HttpServlet
{
	String className = this.getClass().getSimpleName();
	private static final SearchSettings settings = SearchSettings.getInstance("search.properties");


	private String availString()
	{ 
		boolean available;
		int obstapRowCount = -1;
		DbObstap dbObstap;
		String note;
		try
		{
			synchronized(DbObstap.class)
			{
				dbObstap = new DbObstap(settings.dbConnArgs);
			}
			obstapRowCount = dbObstap.queryObstapRowCount();
			available = (obstapRowCount >= 0);
			note = "Table obstap in " + settings.dbConnArgs.toString() + " has "
					+ String.valueOf(obstapRowCount)  + " rows";
		}
		catch(Exception ex)
		{
			note = "Accessing " + settings.dbConnArgs.toString()
				+ " failed with " + ex.toString();
			available = false;
		}
		String availStr = 
			"<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
			+ "<vosi:availability xmlns:vosi=\"http://www.ivoa.net/xml/VOSIAvailability/v1.0\">"
			+ "<vosi:available> "+ (available ? "true":"false") +" </vosi:available>"
			+ "<vosi:note> VLKB-SIAv2 "+ Version.asString +" is accepting queries </vosi:note>"
			+ "<vosi:note> " + note + " </vosi:note>"
			+ "</vosi:availability>";

		return availStr;
	}


	private String capsStr = null;

	protected void SetCapsStr(String URL, String funcName)
	{
		if(URL != null)
		{

			String accessURL = stripTrailingSlash(URL);

			capsStr =
				"<?xml version=\"1.0\" encoding=\"UTF-8\"?>"

				+ "<vosi:capabilities "
				+    "xmlns:vosi=\"http://www.ivoa.net/xml/VOSICapabilities/v1.0\" "
				+    "xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" "
				+    "xmlns:vod=\"http://www.ivoa.net/xml/VODataService/v1.1\">"

				+ " <capability standardID=\"ivo://ivoa.net/std/VOSI#capabilities\">"
				+ "   <interface xsi:type=\"vod:ParamHTTP\" version=\"1.0\">"
				+ "     <accessURL use=\"full\">"
				+          accessURL + "/capabilities"
				+ "     </accessURL>"
				+ "   </interface>"
				+ " </capability>"

				+ " <capability standardID=\"ivo://ivoa.net/std/VOSI#availability\">"
				+ "   <interface xsi:type=\"vod:ParamHTTP\" version=\"1.0\">"
				+ "     <accessURL use=\"full\">"
				+          accessURL + "/availability"
				+ "     </accessURL>"
				+ "   </interface>"
				+ " </capability>"

				+ " <capability standardID=\"ivo://ivoa.net/std/SIA#query-2.0\">"
				+ "   <interface xsi:type=\"vod:ParamHTTP\" role=\"std\" version=\"2.0\">"
				+ "     <accessURL>"
				+          accessURL + "/" + funcName
				+ "     </accessURL>"
				+ "   </interface>"
				+ " </capability>"

				+ "</vosi:capabilities>";
		}
	}


	String stripTrailingSlash(String path)
	{
		if (path.endsWith("/"))
			return path.substring(0,path.length()-1);
		else
			return path;
	}


	protected void doGet(HttpServletRequest request,
			HttpServletResponse response)
		throws ServletException, IOException {

			doPost(request, response);
		}



	protected void doPost(HttpServletRequest request,
			HttpServletResponse response)
		throws ServletException, IOException
		{
			StringBuffer requestURL = request.getRequestURL();

			//System.out.println(className + " vlkb req from: " + request.getRemoteAddr()
			//                         + " doGet: " + requestURL.toString());

			PrintWriter writer = response.getWriter();
			response.setContentType("text/xml");

			if(-1 != requestURL.lastIndexOf("/capabilities"))
			{
				String fullURL = request.getRequestURL().toString();
				String baseURL = fullURL.substring(0,requestURL.lastIndexOf("/"));

				SetCapsStr(baseURL, "query");
				writer.println(capsStr);	

			}
			else if(-1 != requestURL.lastIndexOf("/availability"))
			{
				writer.println(availString());	
			}
			// error FIXME what to do if none of above given ? e.g. misconfigured web.xml

			writer.close();
			return;
		}
}

