
import java.io.PrintWriter;

// VOTable
import uk.ac.starlink.table.*;// StarTable needed
import uk.ac.starlink.votable.*;// Writer needed

import java.io.IOException;
import java.io.OutputStreamWriter;
import java.io.BufferedWriter;

import java.util.List;
import java.util.ArrayList;

import vo.parameter.*;

final class XmlSerializer
{
   private XmlSerializer() {}

   // VOTable

   public static void serializeToVoTable(
         PrintWriter writer, String charEncoding,
         DbObstap.Obstap[] obstapArr,
         String cutoutUrl,
         boolean showDuration, long startTime_msec) throws IOException
   {
      RowListStarTable dstable = new RowListStarTable( VoTableObstap.OBSTAP_VLKB_COLINFO );

      for(DbObstap.Obstap obstap : obstapArr)
      {
         dstable.addRow( VoTableObstap.obstapVlkbRow(obstap) );
      }


      dstable.setParameter(new DescribedValue(
               new DefaultValueInfo("datasets count", Integer.class, "Count of all datasets from VLKB-search" ),
               obstapArr.length ) );

      if(showDuration)
      {
         dstable.setParameter(new DescribedValue(
                  new DefaultValueInfo("exec time", Long.class, "Execution time in [msec]" ),
                  System.currentTimeMillis() - startTime_msec ) );
      }

      BufferedWriter out = new BufferedWriter( writer );

      out.write("<?xml-stylesheet type='text/xsl' href='VOTable2XHTML.xsl'?>");
      out.write( "<VOTABLE version='1.1'>" );
      out.write( "<RESOURCE type=\"results\">" );
      out.write( "<DESCRIPTION> " + Version.asString + " </DESCRIPTION>" );

      VOSerializer.makeSerializer( DataFormat.TABLEDATA, dstable ).writeInlineTableElement( out );

      out.write( "</RESOURCE>" );

      out.write( "<RESOURCE type=\"meta\" utype=\"adhoc:service\" name=\"CutoutService\" >" );
      out.write( "<DESCRIPTION> VLKB cutout service </DESCRIPTION>");
      out.write( "<PARAM name=\"standardID\" datatype=\"char\" arraysize=\"*\" value=\"ivo://ivoa.net/std/SODA#sync-1.0\" />");
      out.write( "<PARAM name=\"accessURL\" datatype=\"char\" arraysize=\"*\" value=\"" + cutoutUrl +  "\" />");
      out.write( "<GROUP name=\"inputParams\">");
      out.write( "<PARAM name=\"ID\" datatype=\"char\" arraysize=\"*\" value=\"\" ref=\"primaryID\" />"); // FIXME results table obs_publisher_did FIELD must have attrib: ID="primaryID"
      out.write( "</GROUP>");
      out.write( "</RESOURCE>" );

      out.write( "</VOTABLE>" );
      out.flush();
   }

}
